@@ -1,4 +1,7 @@
+/*
 #include <assert.h>
+*/
+
 #include "mcga.h"
 #include "dejong.h"
 
@@ -6,19 +9,19 @@ double dejong_anormal =0.0;
 
 double dejongcost1 (struct Chromosome *c)
 {
-    assert(c->ch_size == 3);
+    /* assert(c->ch_size == 3); */
     return(dejong1(c->genes));
 }
 
 double dejongcost2 (struct Chromosome *c)
 {
-    assert(c->ch_size == 2);
+    /* assert(c->ch_size == 2); */
     return(dejong2(c->genes));
 }
 
 double dejongcost3 (struct Chromosome *c)
 {
-    assert(c->ch_size == 5);
+    /* assert(c->ch_size == 5); */
     return(dejong3(c->genes));
 }
 
